summaryrefslogtreecommitdiff
path: root/buildscripts
diff options
context:
space:
mode:
authorZakhar Kleyman <zakhar.kleyman@mongodb.com>2017-02-16 12:03:22 -0500
committerZakhar Kleyman <zakhar.kleyman@mongodb.com>2017-02-21 11:31:07 -0500
commit7ba5e3f4961be80b99a7dc69f84ed74309da59b2 (patch)
treee055dd94a8bccd67d85aed2a53d1aa5f57e825f2 /buildscripts
parent16ee301e2c958905d859378ab5ef316c9bf05308 (diff)
downloadmongo-7ba5e3f4961be80b99a7dc69f84ed74309da59b2.tar.gz
SERVER-25309 add rhel6 zSeries build variant
Diffstat (limited to 'buildscripts')
-rwxr-xr-xbuildscripts/packager-enterprise.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/buildscripts/packager-enterprise.py b/buildscripts/packager-enterprise.py
index c7783c98dfe..8629be1963f 100755
--- a/buildscripts/packager-enterprise.py
+++ b/buildscripts/packager-enterprise.py
@@ -106,7 +106,7 @@ class EnterpriseDistro(packager.Distro):
raise Exception("BUG: unsupported platform?")
def build_os(self, arch):
"""Return the build os label in the binary package to download ("rhel57", "rhel62" and "rhel70"
for redhat, the others are delegated to the super class
"""
if arch == "ppc64le":
@@ -118,7 +118,7 @@ class EnterpriseDistro(packager.Distro):
return []
if arch == "s390x":
if self.n == 'redhat':
- return [ "rhel72" ]
+ return [ "rhel67", "rhel72" ]
if self.n == 'suse':
return [ "suse11", "suse12" ]
if self.n == 'ubuntu':
@@ -106,7 +106,7 @@ class EnterpriseDistro(packager.Distro):
raise Exception("BUG: unsupported platform?")
def build_os(self, arch):
- """Return the build os label in the binary package to download ("rhel57", "rhel62" and "rhel70"
+ """Return the build os label in the binary package to download ("rhel57", "rhel62", "rhel67" and "rhel70"
for redhat, the others are delegated to the super class
"""